@@ -99,8 +99,8 @@ class Payments(Resource):
 
             data["type"] = "SalesPayment"
 
-            if 'payment_type' in payload.keys():
-                data["type"] = payload.get("payment_type", "SalesPayment")
+            if 'type' in payload.keys():
+                data["type"] = payload.get("type", "SalesPayment")
 
             additional_properties = payload.get("additional_properties", {})
 
@@ -119,25 +119,32 @@ class Payments(Resource):
                         }
                     })
 
+                if 'account_id' in payload.keys():
+                    data.update({
+                        "DepositToAccountRef": {
+                            "value": payload.get("account_id", "")
+                        }
+                    })
+
                 if 'reference' in payload.keys():
                     data.update({
                         "PaymentRefNum": payload.get("reference", "")
                     })
                 
-                invoices = payload.get("invoices", [])
+                invoices = payload.get("invoice_payments", [])
 
                 for i in range(len(invoices)):
                     invoice = {}
                     if 'amount' in invoices[i].keys():
                         invoice.update({
-                            "Amount": payload.get("amount", "")
+                            "Amount": invoices[i].get("amount", "")
                         })
 
                     if 'invoice_id' in invoices[i].keys():
                         invoice.update({
                             "LinkedTxn": [
                                 {
-                                    "TxnId": invoices[i].pop('invoice_id'),
+                                    "TxnId": invoices[i].get('invoice_id',""),
                                     "TxnType": "Invoice"
                                 }
                             ]
@@ -181,7 +188,7 @@ class Payments(Resource):
                         "date": payload.get("date", "")
                     })
 
-                invoices = payload.get("invoices", [])
+                invoices = payload.get("invoice_payments", [])
 
                 for i in range(len(invoices)):
                     if 'invoice_id' in invoices[i].keys():
@@ -190,7 +197,11 @@ class Payments(Resource):
                     if 'amount' in invoices[i].keys():
                         invoices[i]['amount_applied'] = invoices[i].pop(
                             'amount')
-
+                    
+                    invoices[i].pop('payment_date')
+                    invoices[i].pop('payment_reference')
+                    invoices[i].pop('payment_type')
+                    invoices[i].pop('account_id')
                 # if invoices has data in it
                 if bool(invoices):
                     payment.update({
@@ -263,6 +274,7 @@ class Payments(Resource):
                 invoice_payments = payload.get("invoice_payments", [])
 
                 for i in range(len(invoice_payments)):
+                    invoice_payments[i].pop('invoice_id')
                     if 'payment_date' in invoice_payments[i].keys():
                         invoice_payments[i]['PaymentDate'] = invoice_payments[i].pop(
                             'payment_date')
@@ -313,19 +325,20 @@ class Payments(Resource):
                         "Reference": payload.get("reference", "")
                     })
 
-                if 'customer_id' in payload.keys():
+                if 'account_id' in payload.keys():
                     payment.update({
                         "Account": {
-                            "AccountID": payload.get("customer_id", "")
+                            "AccountID": payload.get("account_id", "")
                         }
                     })
 
-                if 'invoice' in additional_properties.keys():
+                if 'invoice_id' in payload.keys():
                     payment.update({
-                        "Invoice": additional_properties.get("invoice", {})
+                        "Invoice": {
+                            "InvoiceID": payload.get("invoice_id", ""),
+                            "LineItems": payload.get("invoice_payments", []),
+                        }
                     })
-                    
-                    additional_properties.pop("invoice")
 
                 if bool(payment):
                     data.update({
